========================
Hilfe zu Telemeta
========================

Für technische Unterstützung treten Sie bitte unserer Mailingliste bei:

    `http://lists.parisson.com/cgi-bin/mailman/listinfo/telemeta <http://lists.parisson.com/cgi-bin/mailman/listinfo/telemeta>`_

oder kontaktieren Sie uns per Email:

     support@parisson.com

oder Twitter:

    `http://twitter.com/telemeta <http://twitter.com/telemeta>`_

Weitere Informationen über das Telemetasystem finden Sie unter `telemeta.org <http://telemeta.org>`_

Telemeta verwendet die Audiobibliothek Timeside: `code.google.com/p/timeside/ <http://code.google.com/p/timeside/>`_